class MOU:
    def __init__(self, parties=None, purpose=None, terms=None):
        self.parties = parties
        self.purpose = purpose
        self.terms = terms
        self.enforceability = False
