class Spirit:
    def __init__(self,determination=0.0,passion=0.0,vision=0.0,risk_taking=0.0,innovation=0.0,perseverance=0.0,leadership=0.0,dedication=0.0,attention_to_detail=0.0):
        self.determination = determination
        self.passion = passion
        self.vision= vision
        self.risk_taking = risk_taking
        self.innovation = innovation
        self.perseverance = perseverance
        self.leadership =leadership
        self.dedication =dedication
        self.attention_to_detail = attention_to_detail