class ReserveToCapital:
    def __init__(self, company, reserve_capital, shares_before, shares_after, stock_price):
        self.company = company
        self.reserve_capital = reserve_capital
        self.shares_before = shares_before
        self.shares_after = shares_after
        self.stock_price = stock_price
